@@ -235,9 +235,13 @@ simCluster <- function(S, theta, lam, box, cond = list("eps"=0,"minSize"=1),
 #'
 #' Densification of objects within a predefined ball 
 #' 
+#' This densification method requires package\code{\link[GenSA]{GenSA}} to be installed. Additionally for
+#' performance reasons it is recommended to make use of parallization by package 'parallel' installed and 
+#' available or some 'cluster' object derived from it.
+#' 
 #' Parts of the (reinforcement) geometry system are densified in order to account for regions where some
 #' objects stick together more close than in other regions of the simulation box. These so-called
-#' clusters are generated by a densification algorithm minimizing some energy (by function \code{\link[GenSA]{GenSA}})
+#' clusters are generated by a densification algorithm minimizing some energy 
 #' of object positions and their (overlap) distances within an enclosing ball of objects with
 #' a predefined cluster radius. In order to prevent overlaps between objects one possibly has to increase 
 #' the \code{weight} factor iteratively and run it again if some objects happen to overlap. 
@@ -245,9 +249,9 @@ simCluster <- function(S, theta, lam, box, cond = list("eps"=0,"minSize"=1),
 #' @param F					non-overlapping particle system
 #' @param CL				cluster list, defining the different cluster regions
 #' @param box				simulation box
-#' @param ctrl  			control arguments passed to function \code{\link{GenSA}}
+#' @param ctrl  			control arguments passed to function \code{GenSA}
 #' @param weight   			optional: weight factor \code{weight=10} (default)
-#' @param info			    optional: logical, if TRUE return result from "GenSA" call
+#' @param info			    optional: logical, if TRUE return result from \code{GenSA} call
 #' @param cl 				optional: cluster object, see package \code{snow}
 #' @param parallel.option   optional: In case of \code{mclapply} the function \code{mclapply} 
 #' 								      is used from the \code{parallel} package
@@ -259,6 +263,8 @@ simCluster <- function(S, theta, lam, box, cond = list("eps"=0,"minSize"=1),
 densifyCluster <- function(F, CL, box, ctrl, weight = 10, info = FALSE, cl = NULL,
 					parallel.option=getOption("parallel.option","lapply"))
 {	
+	if(!requireNamespace("GenSA", quietly=TRUE))
+	  stop("package 'GenSA' is required to run this function.")
 	densify <- function(L,box,ctrl,weight,FUNCTION) {		
 		S <- L$S
 		dim <- length(S)
@@ -266,7 +272,7 @@ densifyCluster <- function(F, CL, box, ctrl, weight = 10, info = FALSE, cl = NUL
 		maxD <- sapply(S,function(s) sqrt(sum((s$center-clust$center)^2)))
 		# apply GenSA	
 		out <- tryCatch({
-					GenSA(par=0.5*maxD, lower=rep(0,length(S)), upper=0.9*maxD,
+					GenSA::GenSA(par=0.5*maxD, lower=rep(0,length(S)), upper=0.9*maxD,
 				    	 fn = FUNCTION, control = ctrl, S = S, clust = clust, weight = weight)				
 					},
 				  error=function(e) structure(e, error=e) )
@@ -280,9 +286,7 @@ densifyCluster <- function(F, CL, box, ctrl, weight = 10, info = FALSE, cl = NUL
 		msg <- if(info) list("out"=out,"val"=out$value,"maxD"=maxD) else NULL			
 		structure(S, "interior"=TRUE, "info"=msg)
 	}
-	
-	fun <- get(parallel.option)
-	
+			
 	FUN <- NULL
 	if(attr(F,"class")=="prolate" || attr(F,"class")=="oblate") {
 		FUN <- .EnSpheroid						
@@ -303,15 +307,19 @@ densifyCluster <- function(F, CL, box, ctrl, weight = 10, info = FALSE, cl = NUL
 				L <- lapply(seq_len(N),function(i) list("S"=F[CL[[i]]$id],"clust"=CL[[i]])	)
 				if(!is.null(cl)) {				
 					m <- min(N,length(cl))				
-					clusterExport(cl[1:m],list(".getA",".slice",".spheroidTouchDistCoeff",".En",".checkEn"))
+					parallel::clusterExport(cl[1:m],list(".getA",".slice",".spheroidTouchDistCoeff",".En",".checkEn"))
 					if(any(class(cl) %in% c("MPIcluster"))) {
-						parLapplyLB(cl[seq_len(m)],L,densify,box=box,ctrl=ctrl,weight=weight,FUNCTION=FUN)
-					} else {						
-						do.call(c, clusterApply(cl[seq_len(m)], .splitList(L, length(cl)), fun, densify,
+						parallel::parLapplyLB(cl[seq_len(m)],L,densify,box=box,ctrl=ctrl,weight=weight,FUNCTION=FUN)
+					} else {
+						fun <- get(parallel.option)
+						do.call(c, parallel::clusterApply(cl[seq_len(m)], .splitList(L, length(cl)), fun, densify,
 										box=box,ctrl=ctrl,weight=weight,FUNCTION=FUN))	
 					}
 				} else {				
-					fun(L,densify,box=box,ctrl=ctrl,weight=weight,FUNCTION=FUN)						
+					if(parallel.option=="mclapply" && !requireNamespace("parallel", quietly=TRUE))
+					  stop("package 'parallel' is required to run this function in parallel mode.")
+				  	fun <- get(parallel.option)
+				 	fun(L,densify,box=box,ctrl=ctrl,weight=weight,FUNCTION=FUN)						
 				}
 				
 			}
